<?php
namespace Datacake\Core\Admin\ApiViews;

use Datacake\Core\Admin\ApiViews\AbstractApiView;
use Datacake\Core\Wda\ChannelGroupApi;

class ChannelGroupApiView extends AbstractApiView {
    public $taxonomy = "isp_canais_category";
    public function __construct( $args = array()) {
        $this->path = "isp_channel_group_view";
        $this->api = new ChannelGroupApi();
        $this->extraActions = [
            "sync"
        ];
    }
    private function create_or_get_parent_group_category(){
        $term = term_exists( 'Grupos', $this->taxonomy); 
        if($term){
            return $term['term_id'];
        }
        $data = [
            'description' => 'Grupos',
            'slug' => 'grupos',
            'parent' => null,
        ];
        
        $term_id = wp_insert_term('Grupos', $this->taxonomy, $data);
        return $term_id;
        
    }
    function sync(){
        
        $message = [
            "status"=>"error",
            "mensagem" => "starting"
        ];
        $q = $this->api;
        $page = ["number" => 1, "size" => 40];
        if(isset($_POST['page'])){
            $page["number"] = sanitize_key($_POST['page']);
           
        }
        $q = $q->setJsonApiPage($page);
        $q = $q->setJsonApiFields([
            'id','name'
        ]);
        
        
        $response = $q->list();
        
        if($response->isSuccessful()){
            if($response->hasDocument()){
                $parent_id = $this->create_or_get_parent_group_category();
                foreach ($response->document()->primaryResources() as $key => $doc) {
                    $term = term_exists( $doc->attribute('name'), $this->taxonomy ); 
                    $data = [
                        'description' => $doc->attribute('name'),
                        'slug' => $doc->attribute('name'),
                        'parent' => $parent_id,
                    ];
                    
                    if($term){
                        $term_id = wp_update_term($term['term_id'],$this->taxonomy,$data);
                    }else{
                        $term_id = wp_insert_term($doc->attribute('name'),$this->taxonomy,$data);
                    }
                    update_term_meta( $term_id, 'wda_remote_id', $doc->id() );
                    
              	}
			}else{
                $message = [
                    "status"=>"success",
                    "mensagem" => "Sem produtos"
                ];    
            }
        }else{
            // TODO GET ERROR FROM API
            $message = [
                "status"=>"error",
                "mensagem" => "Error from API"
            ];
        }
        $meta = $response->document()->meta();
        if($meta['pagination']['page'] < $meta['pagination']['pages']){
            $message = [
                "status"=>"success",
                "mensagem" => "Sincronização de categorias de canais pagina:".$meta['pagination']['page']." de ".$meta['pagination']['pages']." concluida",
                "next_page" => $meta['pagination']['page'] + 1,
                "pagination" => $meta['pagination']
            ];
        } else {
            $message = [
                "status"=>"success",
                "mensagem" => "Sincronização de categorias de canais concluida",
                "next_page" => null
            ];
        }

        if($message['status'] == "error"){
            return wp_send_json_error($message);
        }
        return wp_send_json_success($message);
		
    }

}   

